References
==========

.. rubric:: References

.. [EvWi2013] Evans, C.G., Winfree, E., 2013. DNA Sticky End Design and Assignment for Robust Algorithmic Self-assembly, in: DNA Computing and Molecular Programming, Lecture Notes in Computer Science. Presented at the International Workshop on DNA-Based Computers, Springer, Cham, pp. 61–75. https://doi.org/10.1007/978-3-319-01928-4_5

.. [EvWi2018] Evans, C.G., Winfree, E., 2018. Optimizing Tile Set Size While Preserving Proofreading with a DNA Self-assembly Compiler, in: DNA 2018, LNCS. D. Doty and H. Dietz, pp. 37–54.

% .. [WiBe2004] Winfree, E., Bekbolatov, R., 2004. Proofreading Tile Sets: Error Correction for Algorithmic Self-Assembly, in: Chen, J., Reif, J. (Eds.), DNA Computing, Lecture Notes in Computer Science. Springer Berlin Heidelberg, pp. 126–144.

.. [ScYW2012] Schulman, R., Yurke, B., Winfree, E., 2012. Robust self-replication of combinatorial information via crystal growth and scission. PNAS 109, 6405–6410. https://doi.org/10.1073/pnas.1117813109
